import math


class Cube:
    """
    Cube Class
    ==========

    Regular unit cube.
    """

    @staticmethod
    def vertices() -> list:
        """
        """
        vertices = [
            [-1, -1, -1],
            [-1, -1, 1],
            [-1, 1, 1],
            [-1, 1, -1],
            [1, -1, -1],
            [1, -1, 1],
            [1, 1, 1],
            [1, 1, -1],
        ]
        return vertices

    @staticmethod
    def faces() -> list:
        """
        """
        faces = [
            [0, 1, 2, 3],
            [4, 5, 6, 7],
            [0, 1, 4, 5],
            [2, 3, 6, 7],
            [0, 3, 4, 7],
            [1, 2, 5, 6],
        ]
        return faces

    @staticmethod
    def calc_area(r: float | int) -> float:
        """

        Formula to calculate area of Cube
        """
        area = 6 * r * r
        return area

    @staticmethod
    def calc_volume(r: float | int) -> float:
        """

        Formula to calculate volume of Cube
        """
        volume = r * r * r
        return volume



# -*- coding: utf-8 -*-


"""
Provides a Dyamxion entry point.
"""


# Import | Futures
from __future__ import print_function
# […]

# Import | Standard Library
import platform
try:
    import pkg_resources
except ImportError:
    pkg_resources = None
# […]

# Import | Libraries
import dymaxion
# […]

# Import | Local Modules
# […]


if __name__ == "__main__":

    print()
    print("Dymaxion is set!")
    print()
    print("Dymaxion: {}".format(dymaxion.__version__))
    print("Python: {} ({})".format(platform.python_version(), platform.python_implementation()))

    if pkg_resources:
        working_set = pkg_resources.working_set
        packages = set([p.project_name for p in working_set]) - set(["Dymaxion"])
        dymaxion_pkgs = [p for p in packages if p.lower().startswith("dymaxion")]

        if dymaxion_pkgs:
            print("Extensions: {}".format([p for p in dymaxion_pkgs]))



# -*- coding: utf-8 -*-


"""
Provides Dymaxion package information.
"""


__author__ =        "Lars van Vianen"
__copyright__ =     "Copyright 2023, Geoid"
__credits__ =       [
                        "Lars van Vianen",
                    ]
__license__ =       "Creative Commons Attribution-ShareAlike 4.0 International License"
__version__ =       "0.0.0"
__maintainer__ =    "Geoid"
__email__ =         "info@geoid.org"
__status__ =        "Alpha"



import math


phi = (math.sqrt(5) + 1) / 2  # golden ratio


class Icosahedron:
    """
    Icosahedron Class
    =================

    Regular unit icosahedron.
    """

    @staticmethod
    def vertices() -> list:
        """
        12 principal directions in 3D space: points on an unit icosahedron.
        """
        vertices = [
            [0, phi, 1],
            [0, phi, -1],
            [0, -phi, 1],
            [0, -phi, -1],
            [1, 0, phi],
            [1, 0, -phi],
            [-1, 0, phi],
            [-1, 0, -phi],
            [phi, 1, 0],
            [phi, -1, 0],
            [-phi, 1, 0],
            [-phi, -1, 0],
        ]
        return vertices

    @staticmethod
    def faces() -> list:
        """
        20 faces
        """
        faces = [
            [0, 5, 1], [0, 3, 5], [0, 2, 3], [0, 4, 2], [0, 1, 4],
            [1, 5, 8], [5, 3, 10], [3, 2, 7], [2, 4, 11], [4, 1, 9],
            [7, 11, 6], [11, 9, 6], [9, 8, 6], [8, 10, 6], [10, 7, 6],
            [2, 11, 7], [4, 9, 11], [1, 8, 9], [5, 10, 8], [3, 7, 10],
        ]
        return faces

    @staticmethod
    def calc_area(a: float | int) -> float:
        """

        Formula to calculate area of Icosahedron
        """
        area = 5 * math.sqrt(3) * a * a
        return area

    @staticmethod
    def calc_volume(a: float | int) -> float:
        """

        Formula to calculate volume of Icosahedron
        """
        volume = ((5 / 12) * (3 + math.sqrt(5)) * a * a * a)
        return volume
